#ifndef _LIBTELETOKEN_H
#define _LIBTELETOKEN_H

#include <linux/types.h>

typedef __u8	uint8_t;
typedef __u16	uint16_t;
typedef __u32	uint32_t;

// --- funkcje eksportowane ---

uint32_t TVTT_GetVersion(uint32_t *Ver, uint32_t *SubVer, uint32_t *APIVer);
uint32_t TVTT_GetSerialNr(uint32_t TokenH, uint32_t TimeOut, uint8_t SerialNr[4]);
uint32_t TVTT_FindToken(uint32_t *TokenH, uint32_t TimeOut, uint32_t OwnerID, uint8_t OwnerMsk,
                        uint8_t Skip, uint32_t *FeatureTblSize, uint32_t *FeatureTbl);
uint32_t TVTT_FreeToken(uint32_t TokenH);
uint32_t TVTT_StartSession(uint32_t TokenH, uint32_t TimeOut);
uint32_t TVTT_EndSession(uint32_t TokenH);
uint32_t TVTT_Talk(uint32_t TokenH, uint32_t TimeOut, uint32_t OutKey, uint8_t *OutDataA,
                   uint8_t *OutDataB, uint32_t *InKey, uint8_t *InDataA, uint8_t *InDataB);

// --- stale biblioteki ---

#define TVTT_BLOCK_A                    0                   /* staa definujca numer bloku danych przy szyfrowaniu pierwszego bloku danych - na potrzeby funkcji generujcej hasa tymczasowe */
#define TVTT_BLOCK_B                    1                   /* staa definujca numer bloku danych przy szyfrowaniu drugiego bloku danych - na potrzeby funkcji generujcej hasa tymczasowe */
#define TVTT_PC2T                       0                   /* staa definujca kierunek przesania wiadomoci z PC do Tokenu - na potrzeby funkcji generujcej hasa tymczasowe */
#define TVTT_T2PC                       1                   /* staa definujca kierunek przesania wiadomoci z Tokenu do PC - na potrzeby funkcji generujcej hasa tymczasowe */

#define TVTT_RAND_INIT_TBL_SIZE         (16*4)              /* staa definiujca rozmiar tablicy inicjujcej generator liczb pseudolosowych */

#define TVTTS_OK                        0

// --- kody bledow zwracane przez biblioteke ---

#define TVTTS_INVALID_HANDLE            0x0100
#define TVTTS_NULL_PTR                  0x0200
#define TVTTS_BAD_PARAM                 0x0300
#define TVTTS_TOO_MANY_OPEN_TOKENS      0x0400
#define TVTTS_USB_DOES_NOT_EXIST        0x0500
#define TVTTS_TOKEN_NOT_FOUND           0x0600
#define TVTTS_TIME_OUT                  0x0700
#define TVTTS_SEQ_EXPIRED               0x0800
#define TVTTS_ALREADY_OPENED            0x0900
#define TVTTS_UNKNOWN_ERROR             0x1000
#define TVTTS_DLL_INIT_FAILED           0xFF00

// --- kody statusu TeleTokenu ---

#define TVTTS_NO_OPEN                   0x11
#define TVTTS_EXPIRED                   0x12
#define TVTTS_DAMAGED                   0x13

#define TVTTS_NOT_SUPPORTED             0x21
#define TVTTS_OUT_OF_RANGE              0x22
#define TVTTS_PROTECTION_NOT_SUPPORTED  0x23

#define TVTTS_PASS_NOT_PERMITTED        0x31
#define TVTTS_NOT_PERMITTED             0x32
#define TVTTS_ACCESS_EXPIRED            0x33

// --- definicja pol tablicy opisujacej mozliwosci TeleTokenu ---

#define TVTTTI_ID                       0
#define TVTTTI_NV_MEM_SIZE              1
#define TVTTTI_RAM_SIZE                 2
#define TVTTTI_PROTECT_MEM_SIZE         3
#define TVTTTI_PASS_TABLE_SIZE          4
#define TVTTTI_BITS_PER_PASS            5
#define TVTTTI_COUNTERS                 6
#define TVTTTI_BITS_PER_COUNTER         7
#define TVTTTI_EXT_VERSION              8
#define TVTTTI_TABLE_SIZE               9

// --- definicja standardowych pol w drugim bloku danych ---

#define TVTTD_CMD                       0
#define TVTTD_STATUS                    0
#define TVTTD_PARAM1                    1
#define TVTTD_PARAM2                    2
#define TVTTD_PARAM3                    3
#define TVTTD_AUTH                      4

// --- kody rozkazow TeleTokenu ---

#define TVTTC_OPEN                      0x01
#define TVTTC_CLOSE                     0x02
#define TVTTC_FORMAT                    0x0F

#define TVTTC_NVMEM_READ                0x11
#define TVTTC_NVMEM_WRITE               0x12
#define TVTTC_NVMEM_WRITE_PROTECT       0x13
#define TVTTC_NVMEM_PROTECT             0x14
#define TVTTC_VMEM_READ                 0x91
#define TVTTC_VMEM_WRITE                0x92

#define TVTTC_ENCRYPT                   0x21
#define TVTTC_DECRYPT                   0x22

#define TVTTC_CNT_READ                  0x31
#define TVTTC_CNT_INC_READ              0x32
#define TVTTC_CNT_DEC_READ              0x33
#define TVTTC_CNT_WRITE                 0x34
#define TVTTC_CNT_INC_ENCRYPT_READ      0x35
#define TVTTC_CNT_WRITE_CONFIG          0x36
#define TVTTC_CNT_SET_CONFIG            0x37
#define TVTTC_CNT_CLR_CONFIG            0x38

#define TVTTC_PASS_WRITE                0x41
#define TVTTC_PASS_WRITE_CONFIG         0x42
#define TVTTC_PASS_SET_CONFIG           0x43
#define TVTTC_PASS_CLR_CONFIG           0x44

// --- bity konfiguracji hasel ---

#define TVTTPC0_TOKEN                   0x01
#define TVTTPC0_PASS_WRITE              0x02
#define TVTTPC0_PASS_CONFIG             0x04
#define TVTTPC0_MEM_READ                0x08
#define TVTTPC0_MEM_WRITE               0x10
#define TVTTPC0_ENCRYPT                 0x20
#define TVTTPC0_DECRYPT                 0x40

#define TVTTPC1_CNT_READ                0x01
#define TVTTPC1_CNT_WRITE               0x02
#define TVTTPC1_CNT_CONFIG              0x04
#define TVTTPC1_ENCRYPT_PASS            0x08
#define TVTTPC1_DECRYPT_PASS            0x10
#define TVTTPC1_CNT_ENCRYPT_PASS        0x20
#define TVTTPC1_WRITE_ENABLED           0x40
#define TVTTPC1_CONFIG_ENABLED          0x80

// --- bity konfiguracji licznikow ---

#define TVTTCC0_WRITE                   0x01
#define TVTTCC0_READ                    0x02
#define TVTTCC0_INC_READ                0x04
#define TVTTCC0_DEC_READ                0x08
#define TVTTCC0_INC_ENCRYPT_READ        0x10
#define TVTTCC0_STOP_AT_ZERO            0x20
#define TVTTCC0_NVMEM_READ              0x40
#define TVTTCC0_NVMEM_WRITE             0x80

#define TVTTCC1_PASS                    0x01
#define TVTTCC1_CONFIG_ENABLED          0x80

// --- status zwracany przez funkcje biblioteki - kompatybilnosc z win

#define INVALID_HANDLE_VALUE		0x00

#endif // _LIBTELETOKEN_H
